QuerySetting

Struct QuerySetting 

pub struct QuerySetting<'a> {
    pub name: &'a str,
    pub value: &'a str,
    pub important: bool,
    pub custom: bool,
}
Query setting sent to ClickHouse.

Fields

name: &'a strvalue: &'a strimportant: bool

Requests an error when server does not recognize setting.

custom: bool

Identifies setting as a user-defined custom_* setting.

Implementations

Source

impl<'a> QuerySetting<'a>

pub const fn new(name: &'a str, value: &'a str) -> Self

Creates a built-in setting that server may ignore when unknown.

pub const fn important(self) -> Self

Marks setting as important.

pub const fn custom(self) -> Self

Marks setting as user-defined.

Source

impl QuerySetting<'static>

pub const TEXT_TYPE_NAMES: Self

output_format_native_encode_types_in_binary_format = 0.

Block decoder requires text type names. Include this setting when a server or profile may enable binary type names.